from trix.widgets import TrixEditor


class TrixAdmin(object):

    def formfield_for_dbfield(self, db_field, **kwargs):

        if not hasattr(self, 'trix_fields'):
            raise ValueError('trix_fields is required on model')

        if db_field.name in self.trix_fields:
            return db_field.formfield(widget=TrixEditor())
        return super(TrixAdmin, self).formfield_for_dbfield(db_field, **kwargs)



from __future__ import unicode_literals
from django import forms
from django.contrib.admin import widgets as admin_widgets


class TrixEditor(forms.Textarea):

    def render(self, name, value, attrs=None):

        if attrs is None:
            attrs = {}
        attrs.update({'style': 'visibility: hidden; position: absolute;'})

        id_attr = attrs.get('id') or '{}_id'.format(name)
        html = super(TrixEditor, self).render(name, value, attrs)
        html += """<p><trix-editor input="{}" class="trix-content"></trix-editor></p>""".format(id_attr)
        return html

    class Media:
        css = {'all': ('trix/trix.css',)}
        js = ('trix/trix.js', 'trix/trix-django.js')



from setuptools import setup

long_description = open('README.rst').read()

setup(
    name="django-trix",
    version='0.1',
    packages=["trix"],
    description="Trix rich text editor widget for Django",
    url="https://github.com/istrategylabs/django-trix",
    author="Jeremy Carbaugh",
    author_email="jeremy@isl.co",
    license='BSD',
    long_description=long_description,
    platforms=["any"],
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Web Environment",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
)
